# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AnnouncementSubscriptionsFilterGroupArgs', 'AnnouncementSubscriptionsFilterGroup']

@pulumi.input_type
class AnnouncementSubscriptionsFilterGroupArgs:
    def __init__(__self__, *,
                 announcement_subscription_id: pulumi.Input[str],
                 filters: pulumi.Input[Sequence[pulumi.Input['AnnouncementSubscriptionsFilterGroupFilterArgs']]],
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a AnnouncementSubscriptionsFilterGroup resource.
        :param pulumi.Input[str] announcement_subscription_id: The OCID of the announcement subscription.
        :param pulumi.Input[Sequence[pulumi.Input['AnnouncementSubscriptionsFilterGroupFilterArgs']]] filters: (Updatable) A list of filters against which the Announcements service will match announcements. You cannot have more than one of any given filter type within a filter group.
        :param pulumi.Input[str] name: The name of the filter group. The name must be unique and it cannot be changed. Avoid entering confidential information.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        pulumi.set(__self__, "announcement_subscription_id", announcement_subscription_id)
        pulumi.set(__self__, "filters", filters)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="announcementSubscriptionId")
    def announcement_subscription_id(self) -> pulumi.Input[str]:
        """
        The OCID of the announcement subscription.
        """
        return pulumi.get(self, "announcement_subscription_id")

    @announcement_subscription_id.setter
    def announcement_subscription_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "announcement_subscription_id", value)

    @property
    @pulumi.getter
    def filters(self) -> pulumi.Input[Sequence[pulumi.Input['AnnouncementSubscriptionsFilterGroupFilterArgs']]]:
        """
        (Updatable) A list of filters against which the Announcements service will match announcements. You cannot have more than one of any given filter type within a filter group.
        """
        return pulumi.get(self, "filters")

    @filters.setter
    def filters(self, value: pulumi.Input[Sequence[pulumi.Input['AnnouncementSubscriptionsFilterGroupFilterArgs']]]):
        pulumi.set(self, "filters", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the filter group. The name must be unique and it cannot be changed. Avoid entering confidential information.


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _AnnouncementSubscriptionsFilterGroupState:
    def __init__(__self__, *,
                 announcement_subscription_id: Optional[pulumi.Input[str]] = None,
                 filters: Optional[pulumi.Input[Sequence[pulumi.Input['AnnouncementSubscriptionsFilterGroupFilterArgs']]]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering AnnouncementSubscriptionsFilterGroup resources.
        :param pulumi.Input[str] announcement_subscription_id: The OCID of the announcement subscription.
        :param pulumi.Input[Sequence[pulumi.Input['AnnouncementSubscriptionsFilterGroupFilterArgs']]] filters: (Updatable) A list of filters against which the Announcements service will match announcements. You cannot have more than one of any given filter type within a filter group.
        :param pulumi.Input[str] name: The name of the filter group. The name must be unique and it cannot be changed. Avoid entering confidential information.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        if announcement_subscription_id is not None:
            pulumi.set(__self__, "announcement_subscription_id", announcement_subscription_id)
        if filters is not None:
            pulumi.set(__self__, "filters", filters)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="announcementSubscriptionId")
    def announcement_subscription_id(self) -> Optional[pulumi.Input[str]]:
        """
        The OCID of the announcement subscription.
        """
        return pulumi.get(self, "announcement_subscription_id")

    @announcement_subscription_id.setter
    def announcement_subscription_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "announcement_subscription_id", value)

    @property
    @pulumi.getter
    def filters(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AnnouncementSubscriptionsFilterGroupFilterArgs']]]]:
        """
        (Updatable) A list of filters against which the Announcements service will match announcements. You cannot have more than one of any given filter type within a filter group.
        """
        return pulumi.get(self, "filters")

    @filters.setter
    def filters(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AnnouncementSubscriptionsFilterGroupFilterArgs']]]]):
        pulumi.set(self, "filters", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the filter group. The name must be unique and it cannot be changed. Avoid entering confidential information.


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


class AnnouncementSubscriptionsFilterGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 announcement_subscription_id: Optional[pulumi.Input[str]] = None,
                 filters: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AnnouncementSubscriptionsFilterGroupFilterArgs']]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        This resource provides the Announcement Subscriptions Filter Group resource in Oracle Cloud Infrastructure Announcements Service service.

        Creates a new filter group in the specified announcement subscription.

        This call is subject to an Announcements limit that applies to the total number of requests across all read or write operations. Announcements might throttle this call to reject an otherwise valid request when the total rate of operations exceeds 20 requests per second for a given user. The service might also throttle this call to reject an otherwise valid request when the total rate of operations exceeds 100 requests per second for a given tenancy.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_announcement_subscriptions_filter_group = oci.announcements_service.AnnouncementSubscriptionsFilterGroup("testAnnouncementSubscriptionsFilterGroup",
            announcement_subscription_id=oci_announcements_service_announcement_subscription["test_announcement_subscription"]["id"],
            filters=[oci.announcements_service.AnnouncementSubscriptionsFilterGroupFilterArgs(
                type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                value=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            )])
        ```

        ## Import

        AnnouncementSubscriptionsFilterGroups can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:AnnouncementsService/announcementSubscriptionsFilterGroup:AnnouncementSubscriptionsFilterGroup test_announcement_subscriptions_filter_group "id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] announcement_subscription_id: The OCID of the announcement subscription.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AnnouncementSubscriptionsFilterGroupFilterArgs']]]] filters: (Updatable) A list of filters against which the Announcements service will match announcements. You cannot have more than one of any given filter type within a filter group.
        :param pulumi.Input[str] name: The name of the filter group. The name must be unique and it cannot be changed. Avoid entering confidential information.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AnnouncementSubscriptionsFilterGroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides the Announcement Subscriptions Filter Group resource in Oracle Cloud Infrastructure Announcements Service service.

        Creates a new filter group in the specified announcement subscription.

        This call is subject to an Announcements limit that applies to the total number of requests across all read or write operations. Announcements might throttle this call to reject an otherwise valid request when the total rate of operations exceeds 20 requests per second for a given user. The service might also throttle this call to reject an otherwise valid request when the total rate of operations exceeds 100 requests per second for a given tenancy.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_announcement_subscriptions_filter_group = oci.announcements_service.AnnouncementSubscriptionsFilterGroup("testAnnouncementSubscriptionsFilterGroup",
            announcement_subscription_id=oci_announcements_service_announcement_subscription["test_announcement_subscription"]["id"],
            filters=[oci.announcements_service.AnnouncementSubscriptionsFilterGroupFilterArgs(
                type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                value=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            )])
        ```

        ## Import

        AnnouncementSubscriptionsFilterGroups can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:AnnouncementsService/announcementSubscriptionsFilterGroup:AnnouncementSubscriptionsFilterGroup test_announcement_subscriptions_filter_group "id"
        ```

        :param str resource_name: The name of the resource.
        :param AnnouncementSubscriptionsFilterGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AnnouncementSubscriptionsFilterGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 announcement_subscription_id: Optional[pulumi.Input[str]] = None,
                 filters: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AnnouncementSubscriptionsFilterGroupFilterArgs']]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AnnouncementSubscriptionsFilterGroupArgs.__new__(AnnouncementSubscriptionsFilterGroupArgs)

            if announcement_subscription_id is None and not opts.urn:
                raise TypeError("Missing required property 'announcement_subscription_id'")
            __props__.__dict__["announcement_subscription_id"] = announcement_subscription_id
            if filters is None and not opts.urn:
                raise TypeError("Missing required property 'filters'")
            __props__.__dict__["filters"] = filters
            __props__.__dict__["name"] = name
        super(AnnouncementSubscriptionsFilterGroup, __self__).__init__(
            'oci:AnnouncementsService/announcementSubscriptionsFilterGroup:AnnouncementSubscriptionsFilterGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            announcement_subscription_id: Optional[pulumi.Input[str]] = None,
            filters: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AnnouncementSubscriptionsFilterGroupFilterArgs']]]]] = None,
            name: Optional[pulumi.Input[str]] = None) -> 'AnnouncementSubscriptionsFilterGroup':
        """
        Get an existing AnnouncementSubscriptionsFilterGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] announcement_subscription_id: The OCID of the announcement subscription.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AnnouncementSubscriptionsFilterGroupFilterArgs']]]] filters: (Updatable) A list of filters against which the Announcements service will match announcements. You cannot have more than one of any given filter type within a filter group.
        :param pulumi.Input[str] name: The name of the filter group. The name must be unique and it cannot be changed. Avoid entering confidential information.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AnnouncementSubscriptionsFilterGroupState.__new__(_AnnouncementSubscriptionsFilterGroupState)

        __props__.__dict__["announcement_subscription_id"] = announcement_subscription_id
        __props__.__dict__["filters"] = filters
        __props__.__dict__["name"] = name
        return AnnouncementSubscriptionsFilterGroup(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="announcementSubscriptionId")
    def announcement_subscription_id(self) -> pulumi.Output[str]:
        """
        The OCID of the announcement subscription.
        """
        return pulumi.get(self, "announcement_subscription_id")

    @property
    @pulumi.getter
    def filters(self) -> pulumi.Output[Sequence['outputs.AnnouncementSubscriptionsFilterGroupFilter']]:
        """
        (Updatable) A list of filters against which the Announcements service will match announcements. You cannot have more than one of any given filter type within a filter group.
        """
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the filter group. The name must be unique and it cannot be changed. Avoid entering confidential information.


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetIpsecConnectionTunnelErrorResult',
    'AwaitableGetIpsecConnectionTunnelErrorResult',
    'get_ipsec_connection_tunnel_error',
    'get_ipsec_connection_tunnel_error_output',
]

@pulumi.output_type
class GetIpsecConnectionTunnelErrorResult:
    """
    A collection of values returned by getIpsecConnectionTunnelError.
    """
    def __init__(__self__, error_code=None, error_description=None, id=None, ipsec_id=None, oci_resources_link=None, solution=None, timestamp=None, tunnel_id=None):
        if error_code and not isinstance(error_code, str):
            raise TypeError("Expected argument 'error_code' to be a str")
        pulumi.set(__self__, "error_code", error_code)
        if error_description and not isinstance(error_description, str):
            raise TypeError("Expected argument 'error_description' to be a str")
        pulumi.set(__self__, "error_description", error_description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ipsec_id and not isinstance(ipsec_id, str):
            raise TypeError("Expected argument 'ipsec_id' to be a str")
        pulumi.set(__self__, "ipsec_id", ipsec_id)
        if oci_resources_link and not isinstance(oci_resources_link, str):
            raise TypeError("Expected argument 'oci_resources_link' to be a str")
        pulumi.set(__self__, "oci_resources_link", oci_resources_link)
        if solution and not isinstance(solution, str):
            raise TypeError("Expected argument 'solution' to be a str")
        pulumi.set(__self__, "solution", solution)
        if timestamp and not isinstance(timestamp, str):
            raise TypeError("Expected argument 'timestamp' to be a str")
        pulumi.set(__self__, "timestamp", timestamp)
        if tunnel_id and not isinstance(tunnel_id, str):
            raise TypeError("Expected argument 'tunnel_id' to be a str")
        pulumi.set(__self__, "tunnel_id", tunnel_id)

    @property
    @pulumi.getter(name="errorCode")
    def error_code(self) -> str:
        """
        Unique code describes the error type.
        """
        return pulumi.get(self, "error_code")

    @property
    @pulumi.getter(name="errorDescription")
    def error_description(self) -> str:
        """
        A detailed description of the error.
        """
        return pulumi.get(self, "error_description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="ipsecId")
    def ipsec_id(self) -> str:
        return pulumi.get(self, "ipsec_id")

    @property
    @pulumi.getter(name="ociResourcesLink")
    def oci_resources_link(self) -> str:
        """
        Link to more Oracle resources or relevant documentation.
        """
        return pulumi.get(self, "oci_resources_link")

    @property
    @pulumi.getter
    def solution(self) -> str:
        """
        Resolution for the error.
        """
        return pulumi.get(self, "solution")

    @property
    @pulumi.getter
    def timestamp(self) -> str:
        """
        Timestamp when the error occurred.
        """
        return pulumi.get(self, "timestamp")

    @property
    @pulumi.getter(name="tunnelId")
    def tunnel_id(self) -> str:
        return pulumi.get(self, "tunnel_id")


class AwaitableGetIpsecConnectionTunnelErrorResult(GetIpsecConnectionTunnelErrorResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetIpsecConnectionTunnelErrorResult(
            error_code=self.error_code,
            error_description=self.error_description,
            id=self.id,
            ipsec_id=self.ipsec_id,
            oci_resources_link=self.oci_resources_link,
            solution=self.solution,
            timestamp=self.timestamp,
            tunnel_id=self.tunnel_id)


def get_ipsec_connection_tunnel_error(ipsec_id: Optional[str] = None,
                                      tunnel_id: Optional[str] = None,
                                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetIpsecConnectionTunnelErrorResult:
    """
    This data source provides details about a specific Ipsec Connection Tunnel Error resource in Oracle Cloud Infrastructure Core service.

    Gets the identified error for the specified IPSec tunnel ID.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_ipsec_connection_tunnel_error = oci.Core.get_ipsec_connection_tunnel_error(ipsec_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        tunnel_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str ipsec_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the IPSec connection.
    :param str tunnel_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the tunnel.
    """
    __args__ = dict()
    __args__['ipsecId'] = ipsec_id
    __args__['tunnelId'] = tunnel_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Core/getIpsecConnectionTunnelError:getIpsecConnectionTunnelError', __args__, opts=opts, typ=GetIpsecConnectionTunnelErrorResult).value

    return AwaitableGetIpsecConnectionTunnelErrorResult(
        error_code=__ret__.error_code,
        error_description=__ret__.error_description,
        id=__ret__.id,
        ipsec_id=__ret__.ipsec_id,
        oci_resources_link=__ret__.oci_resources_link,
        solution=__ret__.solution,
        timestamp=__ret__.timestamp,
        tunnel_id=__ret__.tunnel_id)


@_utilities.lift_output_func(get_ipsec_connection_tunnel_error)
def get_ipsec_connection_tunnel_error_output(ipsec_id: Optional[pulumi.Input[str]] = None,
                                             tunnel_id: Optional[pulumi.Input[str]] = None,
                                             opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetIpsecConnectionTunnelErrorResult]:
    """
    This data source provides details about a specific Ipsec Connection Tunnel Error resource in Oracle Cloud Infrastructure Core service.

    Gets the identified error for the specified IPSec tunnel ID.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_ipsec_connection_tunnel_error = oci.Core.get_ipsec_connection_tunnel_error(ipsec_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        tunnel_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str ipsec_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the IPSec connection.
    :param str tunnel_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the tunnel.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetContainerImageSignatureResult',
    'AwaitableGetContainerImageSignatureResult',
    'get_container_image_signature',
    'get_container_image_signature_output',
]

@pulumi.output_type
class GetContainerImageSignatureResult:
    """
    A collection of values returned by getContainerImageSignature.
    """
    def __init__(__self__, compartment_id=None, created_by=None, display_name=None, id=None, image_id=None, image_signature_id=None, kms_key_id=None, kms_key_version_id=None, message=None, signature=None, signing_algorithm=None, time_created=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if created_by and not isinstance(created_by, str):
            raise TypeError("Expected argument 'created_by' to be a str")
        pulumi.set(__self__, "created_by", created_by)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if image_id and not isinstance(image_id, str):
            raise TypeError("Expected argument 'image_id' to be a str")
        pulumi.set(__self__, "image_id", image_id)
        if image_signature_id and not isinstance(image_signature_id, str):
            raise TypeError("Expected argument 'image_signature_id' to be a str")
        pulumi.set(__self__, "image_signature_id", image_signature_id)
        if kms_key_id and not isinstance(kms_key_id, str):
            raise TypeError("Expected argument 'kms_key_id' to be a str")
        pulumi.set(__self__, "kms_key_id", kms_key_id)
        if kms_key_version_id and not isinstance(kms_key_version_id, str):
            raise TypeError("Expected argument 'kms_key_version_id' to be a str")
        pulumi.set(__self__, "kms_key_version_id", kms_key_version_id)
        if message and not isinstance(message, str):
            raise TypeError("Expected argument 'message' to be a str")
        pulumi.set(__self__, "message", message)
        if signature and not isinstance(signature, str):
            raise TypeError("Expected argument 'signature' to be a str")
        pulumi.set(__self__, "signature", signature)
        if signing_algorithm and not isinstance(signing_algorithm, str):
            raise TypeError("Expected argument 'signing_algorithm' to be a str")
        pulumi.set(__self__, "signing_algorithm", signing_algorithm)
        if time_created and not isinstance(time_created, str):
            raise TypeError("Expected argument 'time_created' to be a str")
        pulumi.set(__self__, "time_created", time_created)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment in which the container repository exists.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> str:
        """
        The id of the user or principal that created the resource.
        """
        return pulumi.get(self, "created_by")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        The last 10 characters of the kmsKeyId, the last 10 characters of the kmsKeyVersionId, the signingAlgorithm, and the last 10 characters of the signatureId.  Example: `wrmz22sixa::qdwyc2ptun::SHA_256_RSA_PKCS_PSS::2vwmobasva`
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the container image signature.  Example: `ocid1.containerimagesignature.oc1..exampleuniqueID`
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the container image.  Example: `ocid1.containerimage.oc1..exampleuniqueID`
        """
        return pulumi.get(self, "image_id")

    @property
    @pulumi.getter(name="imageSignatureId")
    def image_signature_id(self) -> str:
        return pulumi.get(self, "image_signature_id")

    @property
    @pulumi.getter(name="kmsKeyId")
    def kms_key_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the kmsKeyId used to sign the container image.  Example: `ocid1.key.oc1..exampleuniqueID`
        """
        return pulumi.get(self, "kms_key_id")

    @property
    @pulumi.getter(name="kmsKeyVersionId")
    def kms_key_version_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the kmsKeyVersionId used to sign the container image.  Example: `ocid1.keyversion.oc1..exampleuniqueID`
        """
        return pulumi.get(self, "kms_key_version_id")

    @property
    @pulumi.getter
    def message(self) -> str:
        """
        The base64 encoded signature payload that was signed.
        """
        return pulumi.get(self, "message")

    @property
    @pulumi.getter
    def signature(self) -> str:
        """
        The signature of the message field using the kmsKeyId, the kmsKeyVersionId, and the signingAlgorithm.
        """
        return pulumi.get(self, "signature")

    @property
    @pulumi.getter(name="signingAlgorithm")
    def signing_algorithm(self) -> str:
        """
        The algorithm to be used for signing. These are the only supported signing algorithms for container images.
        """
        return pulumi.get(self, "signing_algorithm")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        An RFC 3339 timestamp indicating when the image was created.
        """
        return pulumi.get(self, "time_created")


class AwaitableGetContainerImageSignatureResult(GetContainerImageSignatureResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetContainerImageSignatureResult(
            compartment_id=self.compartment_id,
            created_by=self.created_by,
            display_name=self.display_name,
            id=self.id,
            image_id=self.image_id,
            image_signature_id=self.image_signature_id,
            kms_key_id=self.kms_key_id,
            kms_key_version_id=self.kms_key_version_id,
            message=self.message,
            signature=self.signature,
            signing_algorithm=self.signing_algorithm,
            time_created=self.time_created)


def get_container_image_signature(image_signature_id: Optional[str] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetContainerImageSignatureResult:
    """
    This data source provides details about a specific Container Image Signature resource in Oracle Cloud Infrastructure Artifacts service.

    Get container image signature metadata.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_container_image_signature = oci.Artifacts.get_container_image_signature(image_signature_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str image_signature_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the container image signature.  Example: `ocid1.containersignature.oc1..exampleuniqueID`
    """
    __args__ = dict()
    __args__['imageSignatureId'] = image_signature_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Artifacts/getContainerImageSignature:getContainerImageSignature', __args__, opts=opts, typ=GetContainerImageSignatureResult).value

    return AwaitableGetContainerImageSignatureResult(
        compartment_id=__ret__.compartment_id,
        created_by=__ret__.created_by,
        display_name=__ret__.display_name,
        id=__ret__.id,
        image_id=__ret__.image_id,
        image_signature_id=__ret__.image_signature_id,
        kms_key_id=__ret__.kms_key_id,
        kms_key_version_id=__ret__.kms_key_version_id,
        message=__ret__.message,
        signature=__ret__.signature,
        signing_algorithm=__ret__.signing_algorithm,
        time_created=__ret__.time_created)


@_utilities.lift_output_func(get_container_image_signature)
def get_container_image_signature_output(image_signature_id: Optional[pulumi.Input[str]] = None,
                                         opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetContainerImageSignatureResult]:
    """
    This data source provides details about a specific Container Image Signature resource in Oracle Cloud Infrastructure Artifacts service.

    Get container image signature metadata.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_container_image_signature = oci.Artifacts.get_container_image_signature(image_signature_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str image_signature_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the container image signature.  Example: `ocid1.containersignature.oc1..exampleuniqueID`
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetFleetCryptoAnalysisResultsResult',
    'AwaitableGetFleetCryptoAnalysisResultsResult',
    'get_fleet_crypto_analysis_results',
    'get_fleet_crypto_analysis_results_output',
]

@pulumi.output_type
class GetFleetCryptoAnalysisResultsResult:
    """
    A collection of values returned by getFleetCryptoAnalysisResults.
    """
    def __init__(__self__, aggregation_mode=None, crypto_analysis_result_collections=None, filters=None, fleet_id=None, id=None, managed_instance_id=None, time_end=None, time_start=None):
        if aggregation_mode and not isinstance(aggregation_mode, str):
            raise TypeError("Expected argument 'aggregation_mode' to be a str")
        pulumi.set(__self__, "aggregation_mode", aggregation_mode)
        if crypto_analysis_result_collections and not isinstance(crypto_analysis_result_collections, list):
            raise TypeError("Expected argument 'crypto_analysis_result_collections' to be a list")
        pulumi.set(__self__, "crypto_analysis_result_collections", crypto_analysis_result_collections)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if fleet_id and not isinstance(fleet_id, str):
            raise TypeError("Expected argument 'fleet_id' to be a str")
        pulumi.set(__self__, "fleet_id", fleet_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if managed_instance_id and not isinstance(managed_instance_id, str):
            raise TypeError("Expected argument 'managed_instance_id' to be a str")
        pulumi.set(__self__, "managed_instance_id", managed_instance_id)
        if time_end and not isinstance(time_end, str):
            raise TypeError("Expected argument 'time_end' to be a str")
        pulumi.set(__self__, "time_end", time_end)
        if time_start and not isinstance(time_start, str):
            raise TypeError("Expected argument 'time_start' to be a str")
        pulumi.set(__self__, "time_start", time_start)

    @property
    @pulumi.getter(name="aggregationMode")
    def aggregation_mode(self) -> Optional[str]:
        """
        The result aggregation mode
        """
        return pulumi.get(self, "aggregation_mode")

    @property
    @pulumi.getter(name="cryptoAnalysisResultCollections")
    def crypto_analysis_result_collections(self) -> Sequence['outputs.GetFleetCryptoAnalysisResultsCryptoAnalysisResultCollectionResult']:
        """
        The list of crypto_analysis_result_collection.
        """
        return pulumi.get(self, "crypto_analysis_result_collections")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetFleetCryptoAnalysisResultsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter(name="fleetId")
    def fleet_id(self) -> str:
        """
        The fleet OCID.
        """
        return pulumi.get(self, "fleet_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="managedInstanceId")
    def managed_instance_id(self) -> Optional[str]:
        """
        The managed instance OCID.
        """
        return pulumi.get(self, "managed_instance_id")

    @property
    @pulumi.getter(name="timeEnd")
    def time_end(self) -> Optional[str]:
        return pulumi.get(self, "time_end")

    @property
    @pulumi.getter(name="timeStart")
    def time_start(self) -> Optional[str]:
        return pulumi.get(self, "time_start")


class AwaitableGetFleetCryptoAnalysisResultsResult(GetFleetCryptoAnalysisResultsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetFleetCryptoAnalysisResultsResult(
            aggregation_mode=self.aggregation_mode,
            crypto_analysis_result_collections=self.crypto_analysis_result_collections,
            filters=self.filters,
            fleet_id=self.fleet_id,
            id=self.id,
            managed_instance_id=self.managed_instance_id,
            time_end=self.time_end,
            time_start=self.time_start)


def get_fleet_crypto_analysis_results(aggregation_mode: Optional[str] = None,
                                      filters: Optional[Sequence[pulumi.InputType['GetFleetCryptoAnalysisResultsFilterArgs']]] = None,
                                      fleet_id: Optional[str] = None,
                                      managed_instance_id: Optional[str] = None,
                                      time_end: Optional[str] = None,
                                      time_start: Optional[str] = None,
                                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetFleetCryptoAnalysisResultsResult:
    """
    This data source provides the list of Fleet Crypto Analysis Results in Oracle Cloud Infrastructure Jms service.

    List Crypto Event Analysis results.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_fleet_crypto_analysis_results = oci.Jms.get_fleet_crypto_analysis_results(fleet_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        aggregation_mode=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        managed_instance_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        time_end=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        time_start=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str aggregation_mode: The aggregation mode of the crypto event analysis result.
    :param str fleet_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Fleet.
    :param str managed_instance_id: The Fleet-unique identifier of the related managed instance.
    :param str time_end: The end of the time period during which resources are searched (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
    :param str time_start: The start of the time period during which resources are searched (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
    """
    __args__ = dict()
    __args__['aggregationMode'] = aggregation_mode
    __args__['filters'] = filters
    __args__['fleetId'] = fleet_id
    __args__['managedInstanceId'] = managed_instance_id
    __args__['timeEnd'] = time_end
    __args__['timeStart'] = time_start
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Jms/getFleetCryptoAnalysisResults:getFleetCryptoAnalysisResults', __args__, opts=opts, typ=GetFleetCryptoAnalysisResultsResult).value

    return AwaitableGetFleetCryptoAnalysisResultsResult(
        aggregation_mode=__ret__.aggregation_mode,
        crypto_analysis_result_collections=__ret__.crypto_analysis_result_collections,
        filters=__ret__.filters,
        fleet_id=__ret__.fleet_id,
        id=__ret__.id,
        managed_instance_id=__ret__.managed_instance_id,
        time_end=__ret__.time_end,
        time_start=__ret__.time_start)


@_utilities.lift_output_func(get_fleet_crypto_analysis_results)
def get_fleet_crypto_analysis_results_output(aggregation_mode: Optional[pulumi.Input[Optional[str]]] = None,
                                             filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetFleetCryptoAnalysisResultsFilterArgs']]]]] = None,
                                             fleet_id: Optional[pulumi.Input[str]] = None,
                                             managed_instance_id: Optional[pulumi.Input[Optional[str]]] = None,
                                             time_end: Optional[pulumi.Input[Optional[str]]] = None,
                                             time_start: Optional[pulumi.Input[Optional[str]]] = None,
                                             opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetFleetCryptoAnalysisResultsResult]:
    """
    This data source provides the list of Fleet Crypto Analysis Results in Oracle Cloud Infrastructure Jms service.

    List Crypto Event Analysis results.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_fleet_crypto_analysis_results = oci.Jms.get_fleet_crypto_analysis_results(fleet_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        aggregation_mode=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        managed_instance_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        time_end=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        time_start=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str aggregation_mode: The aggregation mode of the crypto event analysis result.
    :param str fleet_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Fleet.
    :param str managed_instance_id: The Fleet-unique identifier of the related managed instance.
    :param str time_end: The end of the time period during which resources are searched (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
    :param str time_start: The start of the time period during which resources are searched (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetListUserGrantsResult',
    'AwaitableGetListUserGrantsResult',
    'get_list_user_grants',
    'get_list_user_grants_output',
]

@pulumi.output_type
class GetListUserGrantsResult:
    """
    A collection of values returned by getListUserGrants.
    """
    def __init__(__self__, depth_level=None, depth_level_greater_than_or_equal_to=None, depth_level_less_than=None, filters=None, grant_key=None, grant_name=None, grants=None, id=None, privilege_category=None, privilege_type=None, user_assessment_id=None, user_key=None):
        if depth_level and not isinstance(depth_level, int):
            raise TypeError("Expected argument 'depth_level' to be a int")
        pulumi.set(__self__, "depth_level", depth_level)
        if depth_level_greater_than_or_equal_to and not isinstance(depth_level_greater_than_or_equal_to, int):
            raise TypeError("Expected argument 'depth_level_greater_than_or_equal_to' to be a int")
        pulumi.set(__self__, "depth_level_greater_than_or_equal_to", depth_level_greater_than_or_equal_to)
        if depth_level_less_than and not isinstance(depth_level_less_than, int):
            raise TypeError("Expected argument 'depth_level_less_than' to be a int")
        pulumi.set(__self__, "depth_level_less_than", depth_level_less_than)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if grant_key and not isinstance(grant_key, str):
            raise TypeError("Expected argument 'grant_key' to be a str")
        pulumi.set(__self__, "grant_key", grant_key)
        if grant_name and not isinstance(grant_name, str):
            raise TypeError("Expected argument 'grant_name' to be a str")
        pulumi.set(__self__, "grant_name", grant_name)
        if grants and not isinstance(grants, list):
            raise TypeError("Expected argument 'grants' to be a list")
        pulumi.set(__self__, "grants", grants)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if privilege_category and not isinstance(privilege_category, str):
            raise TypeError("Expected argument 'privilege_category' to be a str")
        pulumi.set(__self__, "privilege_category", privilege_category)
        if privilege_type and not isinstance(privilege_type, str):
            raise TypeError("Expected argument 'privilege_type' to be a str")
        pulumi.set(__self__, "privilege_type", privilege_type)
        if user_assessment_id and not isinstance(user_assessment_id, str):
            raise TypeError("Expected argument 'user_assessment_id' to be a str")
        pulumi.set(__self__, "user_assessment_id", user_assessment_id)
        if user_key and not isinstance(user_key, str):
            raise TypeError("Expected argument 'user_key' to be a str")
        pulumi.set(__self__, "user_key", user_key)

    @property
    @pulumi.getter(name="depthLevel")
    def depth_level(self) -> Optional[int]:
        """
        The grant depth level of the indirect grant. An indirectly granted role/privilege is granted to the user through another role. The depth level indicates how deep a privilege is within the grant hierarchy.
        """
        return pulumi.get(self, "depth_level")

    @property
    @pulumi.getter(name="depthLevelGreaterThanOrEqualTo")
    def depth_level_greater_than_or_equal_to(self) -> Optional[int]:
        return pulumi.get(self, "depth_level_greater_than_or_equal_to")

    @property
    @pulumi.getter(name="depthLevelLessThan")
    def depth_level_less_than(self) -> Optional[int]:
        return pulumi.get(self, "depth_level_less_than")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetListUserGrantsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter(name="grantKey")
    def grant_key(self) -> Optional[str]:
        return pulumi.get(self, "grant_key")

    @property
    @pulumi.getter(name="grantName")
    def grant_name(self) -> Optional[str]:
        """
        The name of a user grant.
        """
        return pulumi.get(self, "grant_name")

    @property
    @pulumi.getter
    def grants(self) -> Sequence['outputs.GetListUserGrantsGrantResult']:
        """
        The list of grants.
        """
        return pulumi.get(self, "grants")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="privilegeCategory")
    def privilege_category(self) -> Optional[str]:
        """
        The privilege category.
        """
        return pulumi.get(self, "privilege_category")

    @property
    @pulumi.getter(name="privilegeType")
    def privilege_type(self) -> Optional[str]:
        """
        The type of a user grant.
        """
        return pulumi.get(self, "privilege_type")

    @property
    @pulumi.getter(name="userAssessmentId")
    def user_assessment_id(self) -> str:
        return pulumi.get(self, "user_assessment_id")

    @property
    @pulumi.getter(name="userKey")
    def user_key(self) -> str:
        return pulumi.get(self, "user_key")


class AwaitableGetListUserGrantsResult(GetListUserGrantsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetListUserGrantsResult(
            depth_level=self.depth_level,
            depth_level_greater_than_or_equal_to=self.depth_level_greater_than_or_equal_to,
            depth_level_less_than=self.depth_level_less_than,
            filters=self.filters,
            grant_key=self.grant_key,
            grant_name=self.grant_name,
            grants=self.grants,
            id=self.id,
            privilege_category=self.privilege_category,
            privilege_type=self.privilege_type,
            user_assessment_id=self.user_assessment_id,
            user_key=self.user_key)


def get_list_user_grants(depth_level: Optional[int] = None,
                         depth_level_greater_than_or_equal_to: Optional[int] = None,
                         depth_level_less_than: Optional[int] = None,
                         filters: Optional[Sequence[pulumi.InputType['GetListUserGrantsFilterArgs']]] = None,
                         grant_key: Optional[str] = None,
                         grant_name: Optional[str] = None,
                         privilege_category: Optional[str] = None,
                         privilege_type: Optional[str] = None,
                         user_assessment_id: Optional[str] = None,
                         user_key: Optional[str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetListUserGrantsResult:
    """
    This data source provides the list of List User Grants in Oracle Cloud Infrastructure Data Safe service.

    Gets a list of grants for a particular user in the specified user assessment. A user grant contains details such as the
    privilege name, type, category, and depth level. The depth level indicates how deep in the hierarchy of roles granted to
    roles a privilege grant is. The userKey in this operation is a system-generated identifier. Perform the operation ListUsers
    to get the userKey for a particular user.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_list_user_grants = oci.DataSafe.get_list_user_grants(user_assessment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        user_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        depth_level=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        depth_level_greater_than_or_equal_to=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        depth_level_less_than=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        grant_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        grant_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        privilege_category=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        privilege_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param int depth_level: A filter to return only items that match the specified user grant depth level.
    :param int depth_level_greater_than_or_equal_to: A filter to return only items that are at a level greater than or equal to the specified user grant depth level.
    :param int depth_level_less_than: A filter to return only items that are at a level less than the specified user grant depth level.
    :param str grant_key: A filter to return only items that match the specified user grant key.
    :param str grant_name: A filter to return only items that match the specified user grant name.
    :param str privilege_category: A filter to return only items that match the specified user privilege category.
    :param str privilege_type: A filter to return only items that match the specified privilege grant type.
    :param str user_assessment_id: The OCID of the user assessment.
    :param str user_key: The unique user key. This is a system-generated identifier. ListUsers gets the user key for a user.
    """
    __args__ = dict()
    __args__['depthLevel'] = depth_level
    __args__['depthLevelGreaterThanOrEqualTo'] = depth_level_greater_than_or_equal_to
    __args__['depthLevelLessThan'] = depth_level_less_than
    __args__['filters'] = filters
    __args__['grantKey'] = grant_key
    __args__['grantName'] = grant_name
    __args__['privilegeCategory'] = privilege_category
    __args__['privilegeType'] = privilege_type
    __args__['userAssessmentId'] = user_assessment_id
    __args__['userKey'] = user_key
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:DataSafe/getListUserGrants:getListUserGrants', __args__, opts=opts, typ=GetListUserGrantsResult).value

    return AwaitableGetListUserGrantsResult(
        depth_level=__ret__.depth_level,
        depth_level_greater_than_or_equal_to=__ret__.depth_level_greater_than_or_equal_to,
        depth_level_less_than=__ret__.depth_level_less_than,
        filters=__ret__.filters,
        grant_key=__ret__.grant_key,
        grant_name=__ret__.grant_name,
        grants=__ret__.grants,
        id=__ret__.id,
        privilege_category=__ret__.privilege_category,
        privilege_type=__ret__.privilege_type,
        user_assessment_id=__ret__.user_assessment_id,
        user_key=__ret__.user_key)


@_utilities.lift_output_func(get_list_user_grants)
def get_list_user_grants_output(depth_level: Optional[pulumi.Input[Optional[int]]] = None,
                                depth_level_greater_than_or_equal_to: Optional[pulumi.Input[Optional[int]]] = None,
                                depth_level_less_than: Optional[pulumi.Input[Optional[int]]] = None,
                                filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetListUserGrantsFilterArgs']]]]] = None,
                                grant_key: Optional[pulumi.Input[Optional[str]]] = None,
                                grant_name: Optional[pulumi.Input[Optional[str]]] = None,
                                privilege_category: Optional[pulumi.Input[Optional[str]]] = None,
                                privilege_type: Optional[pulumi.Input[Optional[str]]] = None,
                                user_assessment_id: Optional[pulumi.Input[str]] = None,
                                user_key: Optional[pulumi.Input[str]] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetListUserGrantsResult]:
    """
    This data source provides the list of List User Grants in Oracle Cloud Infrastructure Data Safe service.

    Gets a list of grants for a particular user in the specified user assessment. A user grant contains details such as the
    privilege name, type, category, and depth level. The depth level indicates how deep in the hierarchy of roles granted to
    roles a privilege grant is. The userKey in this operation is a system-generated identifier. Perform the operation ListUsers
    to get the userKey for a particular user.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_list_user_grants = oci.DataSafe.get_list_user_grants(user_assessment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        user_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        depth_level=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        depth_level_greater_than_or_equal_to=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        depth_level_less_than=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        grant_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        grant_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        privilege_category=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        privilege_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param int depth_level: A filter to return only items that match the specified user grant depth level.
    :param int depth_level_greater_than_or_equal_to: A filter to return only items that are at a level greater than or equal to the specified user grant depth level.
    :param int depth_level_less_than: A filter to return only items that are at a level less than the specified user grant depth level.
    :param str grant_key: A filter to return only items that match the specified user grant key.
    :param str grant_name: A filter to return only items that match the specified user grant name.
    :param str privilege_category: A filter to return only items that match the specified user privilege category.
    :param str privilege_type: A filter to return only items that match the specified privilege grant type.
    :param str user_assessment_id: The OCID of the user assessment.
    :param str user_key: The unique user key. This is a system-generated identifier. ListUsers gets the user key for a user.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetJavaReleaseResult',
    'AwaitableGetJavaReleaseResult',
    'get_java_release',
    'get_java_release_output',
]

@pulumi.output_type
class GetJavaReleaseResult:
    """
    A collection of values returned by getJavaRelease.
    """
    def __init__(__self__, artifact_content_types=None, artifacts=None, family_details=None, family_version=None, id=None, license_details=None, license_type=None, parent_release_version=None, release_date=None, release_notes_url=None, release_type=None, release_version=None, security_status=None):
        if artifact_content_types and not isinstance(artifact_content_types, list):
            raise TypeError("Expected argument 'artifact_content_types' to be a list")
        pulumi.set(__self__, "artifact_content_types", artifact_content_types)
        if artifacts and not isinstance(artifacts, list):
            raise TypeError("Expected argument 'artifacts' to be a list")
        pulumi.set(__self__, "artifacts", artifacts)
        if family_details and not isinstance(family_details, list):
            raise TypeError("Expected argument 'family_details' to be a list")
        pulumi.set(__self__, "family_details", family_details)
        if family_version and not isinstance(family_version, str):
            raise TypeError("Expected argument 'family_version' to be a str")
        pulumi.set(__self__, "family_version", family_version)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if license_details and not isinstance(license_details, list):
            raise TypeError("Expected argument 'license_details' to be a list")
        pulumi.set(__self__, "license_details", license_details)
        if license_type and not isinstance(license_type, str):
            raise TypeError("Expected argument 'license_type' to be a str")
        pulumi.set(__self__, "license_type", license_type)
        if parent_release_version and not isinstance(parent_release_version, str):
            raise TypeError("Expected argument 'parent_release_version' to be a str")
        pulumi.set(__self__, "parent_release_version", parent_release_version)
        if release_date and not isinstance(release_date, str):
            raise TypeError("Expected argument 'release_date' to be a str")
        pulumi.set(__self__, "release_date", release_date)
        if release_notes_url and not isinstance(release_notes_url, str):
            raise TypeError("Expected argument 'release_notes_url' to be a str")
        pulumi.set(__self__, "release_notes_url", release_notes_url)
        if release_type and not isinstance(release_type, str):
            raise TypeError("Expected argument 'release_type' to be a str")
        pulumi.set(__self__, "release_type", release_type)
        if release_version and not isinstance(release_version, str):
            raise TypeError("Expected argument 'release_version' to be a str")
        pulumi.set(__self__, "release_version", release_version)
        if security_status and not isinstance(security_status, str):
            raise TypeError("Expected argument 'security_status' to be a str")
        pulumi.set(__self__, "security_status", security_status)

    @property
    @pulumi.getter(name="artifactContentTypes")
    def artifact_content_types(self) -> Sequence[str]:
        """
        Artifact content types for the Java version.
        """
        return pulumi.get(self, "artifact_content_types")

    @property
    @pulumi.getter
    def artifacts(self) -> Sequence['outputs.GetJavaReleaseArtifactResult']:
        """
        List of Java artifacts.
        """
        return pulumi.get(self, "artifacts")

    @property
    @pulumi.getter(name="familyDetails")
    def family_details(self) -> Sequence['outputs.GetJavaReleaseFamilyDetailResult']:
        """
        Metadata associated with a specific Java release family. A Java release family is typically a major version in the Java version identifier.
        """
        return pulumi.get(self, "family_details")

    @property
    @pulumi.getter(name="familyVersion")
    def family_version(self) -> str:
        """
        Java release family identifier.
        """
        return pulumi.get(self, "family_version")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="licenseDetails")
    def license_details(self) -> Sequence['outputs.GetJavaReleaseLicenseDetailResult']:
        """
        Information about a license type for Java.
        """
        return pulumi.get(self, "license_details")

    @property
    @pulumi.getter(name="licenseType")
    def license_type(self) -> str:
        """
        License type for the Java version.
        """
        return pulumi.get(self, "license_type")

    @property
    @pulumi.getter(name="parentReleaseVersion")
    def parent_release_version(self) -> str:
        """
        Parent Java release version identifier. This is applicable for BPR releases.
        """
        return pulumi.get(self, "parent_release_version")

    @property
    @pulumi.getter(name="releaseDate")
    def release_date(self) -> str:
        """
        The release date of the Java version (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
        """
        return pulumi.get(self, "release_date")

    @property
    @pulumi.getter(name="releaseNotesUrl")
    def release_notes_url(self) -> str:
        """
        Release notes associated with the Java version.
        """
        return pulumi.get(self, "release_notes_url")

    @property
    @pulumi.getter(name="releaseType")
    def release_type(self) -> str:
        """
        Release category of the Java version.
        """
        return pulumi.get(self, "release_type")

    @property
    @pulumi.getter(name="releaseVersion")
    def release_version(self) -> str:
        """
        Java release version identifier.
        """
        return pulumi.get(self, "release_version")

    @property
    @pulumi.getter(name="securityStatus")
    def security_status(self) -> str:
        """
        The security status of the Java version.
        """
        return pulumi.get(self, "security_status")


class AwaitableGetJavaReleaseResult(GetJavaReleaseResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetJavaReleaseResult(
            artifact_content_types=self.artifact_content_types,
            artifacts=self.artifacts,
            family_details=self.family_details,
            family_version=self.family_version,
            id=self.id,
            license_details=self.license_details,
            license_type=self.license_type,
            parent_release_version=self.parent_release_version,
            release_date=self.release_date,
            release_notes_url=self.release_notes_url,
            release_type=self.release_type,
            release_version=self.release_version,
            security_status=self.security_status)


def get_java_release(release_version: Optional[str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetJavaReleaseResult:
    """
    This data source provides details about a specific Java Release resource in Oracle Cloud Infrastructure Jms service.

    Returns detail of a Java release.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_java_release = oci.Jms.get_java_release(release_version=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str release_version: Unique Java release version identifier
    """
    __args__ = dict()
    __args__['releaseVersion'] = release_version
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Jms/getJavaRelease:getJavaRelease', __args__, opts=opts, typ=GetJavaReleaseResult).value

    return AwaitableGetJavaReleaseResult(
        artifact_content_types=__ret__.artifact_content_types,
        artifacts=__ret__.artifacts,
        family_details=__ret__.family_details,
        family_version=__ret__.family_version,
        id=__ret__.id,
        license_details=__ret__.license_details,
        license_type=__ret__.license_type,
        parent_release_version=__ret__.parent_release_version,
        release_date=__ret__.release_date,
        release_notes_url=__ret__.release_notes_url,
        release_type=__ret__.release_type,
        release_version=__ret__.release_version,
        security_status=__ret__.security_status)


@_utilities.lift_output_func(get_java_release)
def get_java_release_output(release_version: Optional[pulumi.Input[str]] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetJavaReleaseResult]:
    """
    This data source provides details about a specific Java Release resource in Oracle Cloud Infrastructure Jms service.

    Returns detail of a Java release.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_java_release = oci.Jms.get_java_release(release_version=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str release_version: Unique Java release version identifier
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetConnectHarnessesResult',
    'AwaitableGetConnectHarnessesResult',
    'get_connect_harnesses',
    'get_connect_harnesses_output',
]

@pulumi.output_type
class GetConnectHarnessesResult:
    """
    A collection of values returned by getConnectHarnesses.
    """
    def __init__(__self__, compartment_id=None, connect_harnesses=None, filters=None, id=None, name=None, state=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if connect_harnesses and not isinstance(connect_harnesses, list):
            raise TypeError("Expected argument 'connect_harnesses' to be a list")
        pulumi.set(__self__, "connect_harnesses", connect_harnesses)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The OCID of the compartment that contains the connect harness.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="connectHarnesses")
    def connect_harnesses(self) -> Sequence['outputs.GetConnectHarnessesConnectHarnessResult']:
        """
        The list of connect_harness.
        """
        return pulumi.get(self, "connect_harnesses")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetConnectHarnessesFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        """
        The OCID of the connect harness.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        The name of the connect harness. Avoid entering confidential information.  Example: `JDBCConnector`
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def state(self) -> Optional[str]:
        """
        The current state of the connect harness.
        """
        return pulumi.get(self, "state")


class AwaitableGetConnectHarnessesResult(GetConnectHarnessesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetConnectHarnessesResult(
            compartment_id=self.compartment_id,
            connect_harnesses=self.connect_harnesses,
            filters=self.filters,
            id=self.id,
            name=self.name,
            state=self.state)


def get_connect_harnesses(compartment_id: Optional[str] = None,
                          filters: Optional[Sequence[pulumi.InputType['GetConnectHarnessesFilterArgs']]] = None,
                          id: Optional[str] = None,
                          name: Optional[str] = None,
                          state: Optional[str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetConnectHarnessesResult:
    """
    This data source provides the list of Connect Harnesses in Oracle Cloud Infrastructure Streaming service.

    Lists the connectharness.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_connect_harnesses = oci.Streaming.get_connect_harnesses(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The OCID of the compartment.
    :param str id: A filter to return only resources that match the given ID exactly.
    :param str name: A filter to return only resources that match the given name exactly.
    :param str state: A filter to only return resources that match the given lifecycle state. The state value is case-insensitive.
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    __args__['filters'] = filters
    __args__['id'] = id
    __args__['name'] = name
    __args__['state'] = state
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Streaming/getConnectHarnesses:getConnectHarnesses', __args__, opts=opts, typ=GetConnectHarnessesResult).value

    return AwaitableGetConnectHarnessesResult(
        compartment_id=__ret__.compartment_id,
        connect_harnesses=__ret__.connect_harnesses,
        filters=__ret__.filters,
        id=__ret__.id,
        name=__ret__.name,
        state=__ret__.state)


@_utilities.lift_output_func(get_connect_harnesses)
def get_connect_harnesses_output(compartment_id: Optional[pulumi.Input[str]] = None,
                                 filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetConnectHarnessesFilterArgs']]]]] = None,
                                 id: Optional[pulumi.Input[Optional[str]]] = None,
                                 name: Optional[pulumi.Input[Optional[str]]] = None,
                                 state: Optional[pulumi.Input[Optional[str]]] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetConnectHarnessesResult]:
    """
    This data source provides the list of Connect Harnesses in Oracle Cloud Infrastructure Streaming service.

    Lists the connectharness.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_connect_harnesses = oci.Streaming.get_connect_harnesses(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The OCID of the compartment.
    :param str id: A filter to return only resources that match the given ID exactly.
    :param str name: A filter to return only resources that match the given name exactly.
    :param str state: A filter to only return resources that match the given lifecycle state. The state value is case-insensitive.
    """
    ...
